summaryrefslogtreecommitdiffstats
path: root/src/config.h
diff options
context:
space:
mode:
authorDimitri van Heesch <dimitri@stack.nl>2004-06-17 19:53:53 (GMT)
committerDimitri van Heesch <dimitri@stack.nl>2004-06-17 19:53:53 (GMT)
commit6b195c8d27c7cba3885acf1540f33ea7f51b9d1b (patch)
treee215fcacfb74cc58f4d27e30b9722efd930d7a7a /src/config.h
parent62039dd46dfca33a45f5461a3732b3a707e4ce8b (diff)
downloadDoxygen-6b195c8d27c7cba3885acf1540f33ea7f51b9d1b.zip
Doxygen-6b195c8d27c7cba3885acf1540f33ea7f51b9d1b.tar.gz
Doxygen-6b195c8d27c7cba3885acf1540f33ea7f51b9d1b.tar.bz2
Release-1.3.7-20040617
Diffstat (limited to 'src/config.h')
-rw-r--r--src/config.h10
1 files changed, 8 insertions, 2 deletions
diff --git a/src/config.h b/src/config.h
index 0201329..311bfb8 100644
--- a/src/config.h
+++ b/src/config.h
@@ -502,11 +502,11 @@ class Config
}
/*! @} */
/*! Writes a template configuration file to \a f. If \a shortIndex
* is \c TRUE the description of each configuration option will
* be omitted.
*/
- void writeTemplate(QFile *f,bool shortIndex,bool updateOnly);
+ void writeTemplate(QTextStream &t,bool shortIndex,bool updateOnly);
/////////////////////////////
// internal API
@@ -530,6 +530,12 @@ class Config
/*! Initialize config variables to their default value */
void init();
+ /*! Parse a configuration data in string \a str.
+ * \returns TRUE if successful, or FALSE if the string could not be
+ * parsed.
+ */
+ bool parseString(const char *fn,const char *str);
+
/*! Parse a configuration file with name \a fn.
* \returns TRUE if successful, FALSE if the file could not be
* opened or read.
@@ -502,11 +502,11 @@ class Config
}
/*! @} */
- /*! Writes a template configuration file to \a f. If \a shortIndex
+ /*! Writes a template configuration to stream \a t. If \a shortIndex
* is \c TRUE the description of each configuration option will
* be omitted.